<?php

namespace Litecms\Ourteam\Providers;

use Illuminate\Support\ServiceProvider;

class OurteamServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'ourteam');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'ourteam');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.ourteam', function ($app) {
            return $this->app->make('Litecms\Ourteam\Ourteam');
        });

                // Bind Ourteam to repository
        $this->app->bind(
            'Litecms\Ourteam\Interfaces\OurteamRepositoryInterface',
            \Litecms\Ourteam\Repositories\Eloquent\OurteamRepository::class
        );

        $this->app->register(\Litecms\Ourteam\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Ourteam\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.ourteam'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/ourteam.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/ourteam')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/ourteam')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
